@@ -183,14 +183,15 @@ def init():
                     repo = git.Repo(path)
                     origin = repo.remote(name='origin')
                     res=origin.pull()
-                    print("pull succeessfull")
+                    print("Looking for Pull Opeartion")
                     time.sleep(10)
                     val=0
                 else:
                     print("no files to pull")
                     time.sleep(10)
-          response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name})
-           #success , project id , repo name , current date and time , email id
+          
+          curtime = datetime.datetime.now()          
+          response2 = requests.post('http://35.225.89.124/fetch_log',data={'project_id':project_id,'repo_name':repo_name,'Time ':curtime,'user_name':username})           #success , project id , repo name , current date and time , email id
           print("status code is ",response2.status_code)
 
         except:
